FrameType

Enum FrameType 

pub enum FrameType {
Show 22 variants Hello, Ready, RegisterCommand, RegisterTool, Subscribe, CommandResponse, ToolResult, InterceptResponse, ShutdownAck, Notify, HostRequest, ToolDetailResult, HelloAck, CommandInvoked, ToolInvoke, Event, Intercept, Shutdown, HostResult, SessionMeta, ToolDetailInvoke, Unknown(u16),
}
Frame types with an explicit Unknown arm so peers that do not understand a type still skip the frame by length.

Variants



Hello



Ready



RegisterCommand



RegisterTool



Subscribe



CommandResponse



ToolResult



InterceptResponse



ShutdownAck



Notify



HostRequest



ToolDetailResult



HelloAck



CommandInvoked



ToolInvoke



Event



Intercept



Shutdown



HostResult



SessionMeta



ToolDetailInvoke



Unknown(u16)

Implementations

Source

impl FrameType

pub fn from_u16(v: u16) -> Self

pub fn code(self) -> u16