pub enum FrameType {
Show 22 variants
Hello,
Ready,
RegisterCommand,
RegisterTool,
Subscribe,
CommandResponse,
ToolResult,
InterceptResponse,
ShutdownAck,
Notify,
HostRequest,
ToolDetailResult,
HelloAck,
CommandInvoked,
ToolInvoke,
Event,
Intercept,
Shutdown,
HostResult,
SessionMeta,
ToolDetailInvoke,
Unknown(u16),
}Expand description
Frame types with an explicit Unknown arm so peers
that do not understand a type still skip the frame by length.
Variants
Hello
Ready
RegisterCommand
RegisterTool
Subscribe
CommandResponse
ToolResult
InterceptResponse
ShutdownAck
Notify
HostRequest
ToolDetailResult
HelloAck
CommandInvoked
ToolInvoke
Event
Intercept
Shutdown
HostResult
SessionMeta
ToolDetailInvoke
Unknown(u16)
Implementations